# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - MoinShare library

    @copyright: 2011, 2012 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinSupport import *
from MoinMoin import wikiutil
import re

escape = wikiutil.escape

__version__ = "0.1"

# More Moin 1.9 compatibility functions.

def has_member(request, groupname, username):
    if hasattr(request.dicts, "has_member"):
        return request.dicts.has_member(groupname, username)
    else:
        return username in request.dicts.get(groupname, [])

# Extraction of shared fragments.

marker_regexp_str = r"([{]{3,}|[}]{3,})"
marker_regexp = re.compile(marker_regexp_str, re.MULTILINE | re.DOTALL) # {{{... or }}}...

fragment_prelude = "#!MoinShare "

def getRegions(s):

    "Parse the string 's', returning a list of shared regions."

    regions = []
    marker = None
    is_region = True

    for match_text in marker_regexp.split(s):

        # Capture section text.

        if is_region and marker:
            regions[-1] += match_text

        # Handle section markers.

        elif not is_region:

            # Close any open sections, returning to exposed text regions.

            if marker:
                if match_text.startswith("}") and len(marker) == len(match_text):
                    marker = None

            # Without a current marker, start a section if an appropriate marker
            # is given.

            elif match_text.startswith("{"):
                marker = match_text
                regions.append("")

            # Markers and section text are added to the current region.

            regions[-1] += match_text

        # Exposed text is ignored.

        # The match text alternates between text between markers and the markers
        # themselves.

        is_region = not is_region

    return regions

def getFragmentsFromRegions(regions):

    """
    Return fragments from the given 'regions', each having the form
    (arguments, body text).
    """

    fragments = []

    for region in regions:
        body = region.lstrip("{").rstrip("}")
        if body.startswith(fragment_prelude):
            arguments, body = body[len(fragment_prelude):].split("\n", 1)
            fragments.append((parseAttributes(arguments, False), body))

    return fragments

def getFragments(s):

    """
    Return fragments for the given string 's', each having the form
    (arguments, body text).
    """

    return getFragmentsFromRegions(getRegions(s))

# vim: tabstop=4 expandtab shiftwidth=4
